Planned Updates
---------------

FoV aware positions
+++++++++++++++++++
- Correct coronagraph field locations depending on Lyot optical wedge
- Filter location relative offsets

Detector updates in ngNRC.py
++++++++++++++++++++++++++++
- Pixel glow (dark current) based on subarray size
- Charge diffusion (esp for saturated pixels)
- Persistence/latent image
- Optical distortions
- QE variations across a pixel's surface

PSF Related
+++++++++++
- More PSF Jitter options
- PSF convolution based on geometric spot size

Observation Classes
+++++++++++++++++++
- Photometric time series (incl. weak lens)
- Grism time series
- Wide-field grism
- Wide field imaging (esp. SW modules)

Miscellaneous
+++++++++++++
- DHS mode

